==> HostCMS.Free_6.7.tar.gz: modules/shop/country/location/city/area/i18n/ru.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @subpackage Shop
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2018 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Районы города',
	'show_city_area_title' => "Районы города \"%s\"",
	'show_city_area_link' => "Район",
	'show_city_area_link_add' => "Добавить",
	'add_city_area_tytle' => "Добавление района города",
	'edit_city_area_tytle' => "Редактирование района города",
	'name' => "<acronym title=\"Название района\">Название</acronym>",
	'sorting' => "Порядок сортировки",
	'shop_country_location_city_id' => "Идентификатор города",
	'edit_success' => "Район города успешно добавлен.",
	'edit_error' => "Ошибка добавления района города!",
	'apply_success' => "Район города успешно изменен",
	'apply_error' => "Ошибка изменения района города",
	'markDeleted_success' => "Район города успешно удален!",
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'id' => 'Идентификатор',
	'active' => 'Активность',
	'changeActive_success' => "Информация успешно изменена",	

	'language_tab'=>'Языковые версии',
	'name_en'=>'На английском',
	'name_ru'=>'На русском',
	'name_de'=>'На немецком',
	'name_fr'=>'На французском',
	'name_it'=>'На итальянском',
	'name_es'=>'На испанском',
	'name_pt'=>'На португальском',
	'name_ua'=>'На украинском',
	'name_be'=>'На белорусском',
	'name_pl'=>'На польском',
	'name_lt'=>'На литовском',
	'name_lv'=>'На латышском',
	'name_cz'=>'На чешском',
	'name_ja'=>'На японском',
);

==> HostCMS.Free_7.0.tar.gz: modules/shop/country/location/city/area/i18n/ru.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @subpackage Shop
 * @version 7.x
 * @author Hostmake LLC
 * @copyright © 2005-2023 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Населенные пункты или районы города',
	'show_city_area_title' => "Населенные пункты или районы города \"%s\"",
	'add_city_area_tytle' => "Добавление населенного пункта или района города",
	'edit_city_area_tytle' => 'Редактирование населенного пункта или района города "%s"',
	'name' => "Название",
	'sorting' => "Порядок сортировки",
	'shop_country_location_city_id' => "Идентификатор города",
	'edit_success' => "Район города успешно добавлен.",
	'edit_error' => "Ошибка добавления района города!",
	'apply_success' => "Район города успешно изменен",
	'apply_error' => "Ошибка изменения района города",
	'markDeleted_success' => "Район города успешно удален!",
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'id' => 'Идентификатор',
	'active' => 'Активность',
	'changeActive_success' => "Информация успешно изменена",
	'turnOn_success' => "Районы включены!",
	'switchOff_success' => "Районы выключены!",

	'language_tab'=>'Языковые версии',
	'name_en'=>'На английском',
	'name_ru'=>'На русском',
	'name_de'=>'На немецком',
	'name_fr'=>'На французском',
	'name_it'=>'На итальянском',
	'name_es'=>'На испанском',
	'name_pt'=>'На португальском',
	'name_ua'=>'На украинском',
	'name_be'=>'На белорусском',
	'name_pl'=>'На польском',
	'name_lt'=>'На литовском',
	'name_lv'=>'На латышском',
	'name_cz'=>'На чешском',
	'name_ja'=>'На японском',
);
